extern crate strum;

use structopt::StructOpt;
use strum_macros::EnumString;

#[derive(EnumString, Debug)]
enum Cmd {
    #[strum(
        serialize = "read",
        serialize = "r",
        serialize = "get",
        serialize = "g"
    )]
    Read,
    #[strum(
        serialize = "write",
        serialize = "w",
        serialize = "set",
        serialize = "s"
    )]
    Write,
}

#[derive(Debug, StructOpt)]
#[structopt(name = "curators", about = "An image meta-data handling tool.")]
struct Opt {
    /// image-file to work with.
    image_file: String,

    /// operation
    cmd: Option<Cmd>,

    /// Property to handle.
    property: Option<String>,
}

fn main() {
    let opt = Opt::from_args();
    println!("{:?}", opt);

    match std::fs::File::open(&opt.image_file) {
        Ok(file) => {
            let mut bufreader = std::io::BufReader::new(&file);
            let exifreader = exif::Reader::new();
            match exifreader.read_from_container(&mut bufreader) {
                Ok(exif) => {
                    for f in exif.fields() {
                        println!("{}: {}", f.tag, f.display_value().with_unit(&exif));
                    }
                }
                Err(e) => println!("{:?}", e),
            }
        }
        Err(e) => println!("{:?}", e),
    }
}
